@@ -28,26 +28,30 @@ class GimnlModel:
             ystr,
             zstr,
     ):
-        """Store model results, goodness-of-fit tests, and other information.
+        """Store model results, goodness-of-fit tests, and other information
+        for the Generalized Inflated Multinomial Logit Model.
 
-        :param modeltype: Type of GIMNL Model (bimnl3).
+        :param modeltype: Type of GIMNL Model (bimnl3, simnl3, or timnl3),
+            indicating the inflated category.
         :param reference: Order of categories. The order category will be
-        the first element.
+            the first element.
         :param llik: Log-Likelihood.
         :param coef: Model coefficients.
         :param aic: Model Akaike information .
         :param vcov: Variance-Covariance matrix.
             (optimized as inverted Hessian matrix)
-        :param data: Full dataset.
+        :param data: Model data used for estimation, subsetted to selected
+            variables and missing values listwise deleted.
         :param zs: Inflation stage estimates (Gammas).
-        :param xs: Ordered probit estimates (Betas).
-        :param ycatu: Number of categories in the Dependent Variable (DV).
+        :param xs: Multinomial Logit probit estimates (Betas).
+        :param ycatu: Number of categories in the Dependent variable (DV).
         :param x_: X Data.
         :param yx_: Y (DV) data.
         :param z_: Z Data.
-        :param xstr: list of string for x names.
-        :param ystr: list of string for y names.
-        :param zstr: list of string for z names.
+        :param xstr: List of string for variable names in the MNL stage.
+        :param ystr: List of string for dependent variable name .
+        :param zstr: List of string for variable names in the Logit Split
+        stage.
         """
         self.modeltype = modeltype
         self.reference = reference
@@ -87,23 +91,25 @@ class MnlModel:
             xstr,
             ystr,
     ):
-        """Store model results, goodness-of-fit tests, and other information.
+        """Store model results, goodness-of-fit tests, and other information
+        for the Multinomial Logit Model.
 
         :param modeltype: Type of Model (mnl3).
         :param reference: Order of categories. The order category will be
-        the first element.
+            the first element.
         :param llik: Log-Likelihood.
         :param coef: Model coefficients.
         :param aic: Model Akaike information .
         :param vcov: Variance-Covariance matrix.
             (optimized as inverted Hessian matrix)
-        :param data: Full dataset.
-        :param xs: Ordered probit estimates (Betas).
-        :param ycatu: Number of categories in the Dependent Variable (DV).
+        :param data: Model data used for estimation, subsetted to selected
+            variables and missing values listwise deleted.
+        :param xs: Multinomial Logit estimates (Betas).
+        :param ycatu: Number of categories in the Dependent variable (DV).
         :param x_: X Data.
         :param yx_: Y (DV) data.
-        :param xstr: list of string for x names.
-        :param ystr: list of string for y names.
+        :param xstr: List of string for x names.
+        :param ystr: List of string for y names.
         """
         self.modeltype = modeltype
         self.reference = reference
@@ -122,14 +128,20 @@ class MnlModel:
 
 def mnl3(pstart, x2, x3, y, reference):
     """
-    Likelihood function for the baseline inflated three-category MNL model.
+    Calculate likelihood function for the baseline inflated three-category MNL
+    model.
 
-    :param pstart: starting parameters.
-    :param x2: X covariates.
-    :param x3: X covariates (should be identical to x2.
-    :param y: Dependent Variable (DV).
-    :param z: Inflation stage covariates.
-    :param reference: order of categories.
+    :param pstart: A list of starting parameters.
+    :type pstart: list
+    :param x2: Multinomial Logit variables. Data subsetted to selected
+        variables.
+    :type x2: Pandas dataframe
+    :param x3: Multinomial Logit variables (should be identical to x2.
+    :type x3: Pandas dataframe
+    :param y: Dependent variable (DV). Data subsetted to selected
+        variable.
+    :type y: Pandas dataframe
+    :param reference: List of order of categories.
     """
     b2 = pstart[0: len(x2.columns)]
     b3 = pstart[len(x2.columns): (len(pstart))]
@@ -149,14 +161,24 @@ def mnl3(pstart, x2, x3, y, reference):
 
 def bimnl3(pstart, x2, x3, y, z, reference):
     """
-    Likelihood function for the baseline inflated three-category MNL model.
+    Calculate likelihood function for the baseline inflated three-category
+    MNL model.
 
-    :param pstart: starting parameters.
-    :param x2: X covariates.
-    :param x3: X covariates (should be identical to x2.
-    :param y: Dependent Variable (DV).
-    :param z: Inflation stage covariates.
-    :param reference: order of categories (first category/baseline inflated).
+    :param pstart: A list of starting parameters.
+    :type pstart: list
+    :param x2: Multinomial Logit variables. Data subsetted to selected
+        variables.
+    :type x2: pandas dataframe
+    :param x3: Multinomial Logit variables (should be identical to x2.
+    :type x3: pandas dataframe
+    :param y: Dependent variable (DV). Data subsetted to selected
+        variable.
+    :type y: pandas dataframe
+    :param z: Logit Split stage variables. Data subsetted to selected
+        variables.
+    :type z: pandas dataframe
+    :param reference: List of order of categories (first element will be the
+        inflated category).
     """
     b2 = pstart[len(z.columns): (len(z.columns) + len(x2.columns))]
     b3 = pstart[(len(z.columns) + len(x2.columns)): (len(pstart))]
@@ -179,14 +201,24 @@ def bimnl3(pstart, x2, x3, y, z, reference):
 
 def simnl3(pstart, x2, x3, y, z, reference):
     """
-    Likelihood function for the second category inflated MNL model.
+    Calculate likelihood function for the second category inflated
+    three-category MNL model.
 
-    :param pstart: starting parameters.
-    :param x2: X covariates.
-    :param x3: X covariates (should be identical to x2.
-    :param y: Dependent Variable.
-    :param z: Inflation stage covariates.
-    :param reference: order of categories (second category is inflated).
+    :param pstart: A list of starting parameters.
+    :type pstart: list
+    :param x2: Multinomial Logit variables. Data subsetted to selected
+        variables.
+    :type x2: pandas dataframe
+    :param x3: Multinomial Logit variables (should be identical to x2.
+    :type x3: pandas dataframe
+    :param y: Dependent variable (DV). Data subsetted to selected
+        variable.
+    :type y: pandas dataframe
+    :param z: Logit Split stage variables. Data subsetted to selected
+        variables.
+    :type z: pandas dataframe
+    :param reference: List of order of categories (second element will be the
+        inflated category).
     """
     b2 = pstart[len(z.columns): (len(z.columns) + len(x2.columns))]
     b3 = pstart[(len(z.columns) + len(x2.columns)): (len(pstart))]
@@ -209,14 +241,22 @@ def simnl3(pstart, x2, x3, y, z, reference):
 
 def timnl3(pstart, x2, x3, y, z, reference):
     """
-    Likelihood function for the third category inflated MNL model.
+    Calculate likelihood function for the third category inflated
+    three-category MNL model.
 
-    :param pstart: starting parameters.
-    :param x2: X covariates.
-    :param x3: X covariates (should be identical to x2.
-    :param y: Dependent Variable (DV).
-    :param z: Inflation stage covariates.
-    :param reference: order of categories (third category is inflated).
+    :param pstart: A list of starting parameters.
+    :type pstart: list
+    :param x2: Covariates in the MNL. 
+    :type x2: pandas dataframe
+    :param x3: Multinomial Logit variables (should be identical to x2).
+    :type x3: pandas dataframe
+    :param y: Dependent variable (DV). 
+    :type y: pandas dataframe
+    :param z: Covariates in the Logit model (i.e. split stage). 
+        variables.
+    :type z: pandas dataframe
+    :param reference: List of order of categories (third element will be the
+        inflated category).
     """
     b2 = pstart[len(z.columns): (len(z.columns) + len(x2.columns))]
     b3 = pstart[(len(z.columns) + len(x2.columns)): (len(pstart))]
@@ -244,14 +284,22 @@ def gimnlresults(model, data, x, y, z, modeltype, reference, inflatecat):
     Store estimates, model AIC, and other information to
     :py:class:`GimnlModel`.
 
-    :param model: object model estimated.
-    :param data: dataset.
-    :param x: Multinomial Logit stage covariates.
-    :param y: Dependent Variable (DV).
-    :param z: Spplit-stage covariates.
-    :param modeltype: type of inflated MNL model.
-    :param reference: order of categories.
-    :param inflatecat: inflated category.
+    :param model: Estimation results.
+    :param data: Model data used for estimation, subsetted to selected
+        variables and missing values listwise deleted.
+    :type data: pandas.DataFrame
+    :param x: List of names for covariates in Multinomial Logit stage.
+    :type x: list of str
+    :param y: List of names for dependent variable .
+    :type y: list of str
+    :param z: List of names for covariates in split-stage.
+    :type z: list of str
+    :param modeltype: Type of inflated MNL model. One of 'bimnl3', 'simnl3',
+        or 'timnl3'.
+    :param reference: List of order of categories. First element is the
+        baseline/ reference category.
+    :param inflatecat: Inflated category. One of 'baseline', 'second',
+        or 'third'.
     """
     varlist = np.unique(y + z + x)
     dataset = data[varlist]
@@ -322,14 +370,17 @@ def mnlresults(model, data, x, y, modeltype, reference):
 
     Store estimates, model AIC, and other information to :py:class:`MnlModel`.
 
-    :param model: object model estimated.
-    :param data: dataset.
-    :param x: Multinomial Logit stage covariates.
-    :param y: Dependent Variable (DV).
-    :param z: Spplit-stage covariates.
-    :param modeltype: type of inflated MNL model.
-    :param reference: order of categories.
-    :param inflatecat: inflated category.
+    :param model: Estimation results.
+    :param data: Model data used for estimation, subsetted to selected
+        variables and missing values listwise deleted.
+    :type data: pandas.DataFrame
+    :param x: List of names for covariates in Multinomial Logit stage.
+    :type x: list of str
+    :param y: List of names for dependent variable .
+    :type y: list of str
+    :param modeltype: Three-category MNL model ('mnl3').
+    :param reference: List of order of categories. First element is the
+        baseline/ reference category.
     """
     varlist = np.unique(y + x)
     dataset = data[varlist]
@@ -389,16 +440,30 @@ def gimnlmod(data, x, y, z, reference, inflatecat, method="BFGS", pstart=None):
     """
     Estimate three-category inflated Multinomial Logit model.
 
-    :param data: dataset.
-    :param x: MNL stage covariates.
-    :param y: Dependent Variable. Variable needs to be in factor form,
-            with a number from 0-2 representing each category.
-    :param z: Inflation stage covariates.
-    :param reference: order of categories.
-    :param inflatecat: inflated category. One of "baseline", "second",
-         or "third."
-    :param method: Optimization method.  Default is 'BFGS'
-    :param pstart: Starting parameters.
+    :param data: Full dataset.
+    :type data: pandas.dataframe
+    :param x: Covariates in Multi Nomial Logit stage. The elements must match
+        column names of ``data``.
+    :type x: list of str
+    :param y: Dependent Variable. Values should be integers,
+        with a number from 0-2 representing each category. The element
+        must match column names of ``data``.
+    :type y: list of str
+    :param z: Covariates in split-stage. The elements must match column
+        names of ``data``.
+    :type z: list of str
+    :param reference:  List of three elements specifying the order of
+        categories (e.g [0, 1, 2], [2, 1, 0]. etc...). The first element is
+        the baseline/reference category. The parameter
+        inflatecat then specifies which category in the list inflated.
+    :type reference: list of int
+    :param inflatecat: A string specifying the inflated category. One of
+        "baseline" for the first, "second" for the second, or "third" for the
+        third in reference list to specify the inflated category.
+    :param method: Optimization method.  Default is 'BFGS'. For other
+        available methods, see scipy.optimize.minimize documentation.
+    :param pstart: A list of starting parameters.
+    :type pstart: list
     """
     varlist = np.unique(y + z + x)
     dataset = data[varlist]
@@ -430,7 +495,7 @@ def gimnlmod(data, x, y, z, reference, inflatecat, method="BFGS", pstart=None):
                 pstart,
                 args=(x2, x3, yx_, z_, reference),
                 method=method,
-                options={"gtol": 1e-6, "disp": True, "maxiter": 500},
+                options={"disp": True, "maxiter": 500},
             )
         elif inflatecat == "second":
             model = minimize(
@@ -438,7 +503,7 @@ def gimnlmod(data, x, y, z, reference, inflatecat, method="BFGS", pstart=None):
                 pstart,
                 args=(x2, x3, yx_, z_, reference),
                 method=method,
-                options={"gtol": 1e-6, "disp": True, "maxiter": 500},
+                options={"disp": True, "maxiter": 500},
             )
         elif inflatecat == "third":
             model = minimize(
@@ -446,7 +511,7 @@ def gimnlmod(data, x, y, z, reference, inflatecat, method="BFGS", pstart=None):
                 pstart,
                 args=(x2, x3, yx_, z_, reference),
                 method=method,
-                options={"gtol": 1e-6, "disp": True, "maxiter": 500},
+                options={"disp": True, "maxiter": 500},
             )
     results = gimnlresults(model, data, x, y, z, modeltype, reference,
                            inflatecat)
@@ -457,13 +522,21 @@ def mnlmod(data, x, y, reference, method="BFGS", pstart=None):
     """
     Estimate three-category Multinomial Logit model.
 
-    :param data: dataset.
-    :param x: MNL stage covariates.
-    :param y: Dependent Variable. Variable needs to be in factor form,
-         with a number from 0-2 representing each category.
-    :param reference: order of categories.
-    :param method: Optimization method.  Default is 'BFGS'
-    :param pstart: Starting parameters.
+    :param data: Full dataset.
+    :type data: pandas.dataframe
+    :param x: Covariates in MNL stage. The elements must match column
+        names of ``data``
+    :type x: list of str
+    :param y: Dependent variable. Values should be integers,
+        with a number from 0-2 representing each category.
+    :param reference:  List of three elements specifying the order of
+        categories (e.g [0, 1, 2], [2, 1, 0]. etc...). The first element is
+        the baseline/reference category.
+    :type reference: list of int
+    :param method: Optimization method.  Default is 'BFGS'. For other
+        available methods, see scipy.optimize.minimize documentation.
+    :param pstart: A list of starting parameters.
+    :type pstart: list
     """
     varlist = np.unique(y + x)
     dataset = data[varlist]
@@ -492,7 +565,7 @@ def mnlmod(data, x, y, reference, method="BFGS", pstart=None):
                 pstart,
                 args=(x2, x3, yx_, reference),
                 method=method,
-                options={"gtol": 1e-6, "disp": True, "maxiter": 500},
+                options={"disp": True, "maxiter": 500},
             )
     results = mnlresults(model, data, x, y, modeltype, reference)
     return results
