@@ -27,8 +27,8 @@ class OpModel:
         :param yncat: Number of categories in the outcome variable.
         :param x_: X (Covariates) Data.
         :param yx_: Y (Dependent Variable) data.
-        :param xstr: list of strings for variable(s) in the outcome stage (x).
-        :param ystr: list of strings for outcome variable name (y).
+        :param xstr: List of strings for variable(s) in the outcome stage (x).
+        :param ystr: List of strings for outcome variable name (y).
         """
         self.llik = llik
         self.coefs = coef
@@ -82,9 +82,9 @@ class IopModel:
         :param x_: X Data.
         :param yx_: Y (DV) data.
         :param z_: Z Data.
-        :param xstr: list of strings for x names.
-        :param ystr: list of strings for y names.
-        :param zstr: list of strings for z names.
+        :param xstr: List of strings for x names.
+        :param ystr: List of strings for y names.
+        :param zstr: List of strings for z names.
 
         """
         self.modeltype = modeltype
@@ -145,9 +145,9 @@ class IopCModel:
         :param x_: X Data.
         :param yx_: Y (DV) data.
         :param z_: Z Data.
-        :param xstr: list of strings for x names.
-        :param ystr: list of strings for y names.
-        :param zstr: list of strings for z names.
+        :param xstr: List of strings for x names.
+        :param ystr: List of strings for y names.
+        :param zstr: List of strings for z names.
         """
         self.modeltype = modeltype
         self.llik = llik
@@ -189,18 +189,17 @@ class FittedVals:
 def op(pstart, x, y, data, weights, offsetx):
     """Calculate likelihood function for Ordered Probit Model.
 
-    :param pstart: starting parameters.
-    :type pstart: numpy.ndarray or list.
-    :param x: Ordered stage variables.
-    :type x: pandas.core.frame.DataFrame
-    :param y: DV.
-    :type y: pandas.core.frame.DataFrame
-    :param data: dataset.
-    :type data: pandas.core.frame.DataFrame
-    :param weights: weights.
-    :type weights: int
-    :param offsetx: offset for X.
-    :type offsetx: int
+    :param pstart: A list of starting values for the estimation.
+        Length of the number of parameters to be estimated.
+    :type pstart: list
+    :param x: Covariates for the ordered stage.
+    :type x: pandas.DataFrame
+    :param y: The dependent variable (DV).
+    :type y: pandas.DataFrame
+    :param data: Dataset.
+    :type data: pandas.DataFrame
+    :param weights: Weights.
+    :param offsetx: Offset for covariates in the ordered stage.
     """
     n = len(data)
     ycat = y.astype("category")
@@ -238,22 +237,23 @@ def op(pstart, x, y, data, weights, offsetx):
 def ziop(pstart, x, y, z, data, weights, offsetx, offsetz):
     """Calculate likelihood function for Zero-inflated Model.
 
-    :param pstart: starting parameters.
-    :type pstart: numpy.ndarray or list
-    :param x: Ordered stage variables.
-    :type x: pandas.core.frame.DataFrame
-    :param y: Dependent Variable (DV).
-    :type y: pandas.core.frame.DataFrame
-    :param z: Inflation stage variables.
-    :type z: pandas.core.frame.DataFrame
-    :param data: dataset.
-    :type data: pandas.core.frame.DataFrame
+    :param pstart: A list of starting values for the estimation.
+        Length of the number of parameters to be estimated.
+    :type pstart: list
+    :param x: Covariates for the ordered probit stage. 
+    :type x: pandas.DataFrame
+    :param y: The ordinal dependent Variable (DV). 
+    :type y: pandas.DataFrame
+    :param z: Covariates for the inflation stage. 
+    :type z: pandas.DataFrame
+    :param data: Dataset with missing values listwise deleted.
+    :type data: pandas.DataFrame
     :param weights: weights.
-    :type weights: int
-    :param offsetx: offset for X.
-    :type offsetx: int
-    :param offsetz: offset for z.
-    :type offsetz: int
+    :type weights: float
+    :param offsetx: Offset for the ordered stage covariates (X). 
+    :type offsetx: float
+    :param offsetz: Offset for the inflation stage covariates (Z).
+    :type offsetz: float
     """
     n = len(data)
     ycat = y.astype("category")
@@ -293,22 +293,23 @@ def ziop(pstart, x, y, z, data, weights, offsetx, offsetz):
 def ziopc(pstart, x, y, z, data, weights, offsetx, offsetz):
     """Calculate likelihood function for Zero-inflated Correlated-Errors Model.
 
-    :param pstart: starting parameters.
-    :type pstart: numpy.ndarray or list
-    :param x: Ordered stage variables.
-    :type x: pandas.core.frame.DataFrame
-    :param y: Dependent Variable (DV)
-    :type y: pandas.core.frame.DataFrame
-    :param z: Inflation stage variables.
-    :type z: pandas.core.frame.DataFrame
-    :param data: dataset.
-    :type data: pandas.core.frame.DataFrame
-    :param weights: weights.
-    :type weights: int
-    :param offsetx: offset for X.
-    :type offsetx: int
-    :param offsetz: offset for z.
-    :type offsetz: int
+    :param pstart: A list of starting values for the estimation.
+        Length of the number of parameters to be estimated.
+    :type pstart: list
+    :param x: Covariates for the ordered probit stage. 
+    :type x: pandas.DataFrame
+    :param y: The dependent variable (DV).
+    :type y: pandas.DataFrame
+    :param z: Covariates for the inflation stage. 
+    :type z: pandas.DataFrame
+    :param data: Dataset with missing values listwise deleted.
+    :type data: pandas.DataFrame
+    :param weights: Weights.
+    :type weights: float
+    :param offsetx: Offset for the ordered probit stage covariates (X).
+    :type offsetx: float
+    :param offsetz: Offset for the inflation stage (Z).
+    :type offsetz: float
     """
     n = len(data)
     ycat = y.astype("category")
@@ -371,24 +372,27 @@ def miop(pstart, x, y, z, data, weights, offsetx, offsetz):
     """
     Likelihood function for Middle-inflated Ordered Probit Model
     "without" correlated errors.
-    Number of outcomes must be odd.
 
-    :param pstart: starting parameters.
-    :type pstart: numpy.ndarray or list
-    :param x: Ordered stage variables.
-    :type x: pandas.core.frame.DataFrame
-    :param y: Dependent Variable (DV)
-    :type y: pandas.core.frame.DataFrame
-    :param z: Inflation stage variables.
-    :type z: pandas.core.frame.DataFrame
-    :param data: dataset.
-    :type data: pandas.core.frame.DataFrame
-    :param weights: weights.
-    :type weights: int
-    :param offsetx: offset for X.
-    :type offsetx: int
-    :param offsetz: offset for z.
-    :type offsetz: int
+    The number of categories in the dependent
+    variable must be odd.
+
+    :param pstart: A list of starting values for the estimation.
+        Length of the number of parameters to be estimated.
+    :type pstart: list
+    :param x: Covariates in the ordered probit stage. 
+    :type x: pandas.DataFrame
+    :param y: The dependent variable (DV).
+    :type y: pandas.DataFrame
+    :param z: Covariates in the inflation stage. 
+    :type z: pandas.DataFrame
+    :param data: Dataset with missing values listwise deleted.
+    :type data: pandas.DataFrame
+    :param weights: Weights.
+    :type weights: float
+    :param offsetx: Offset for covariates in the ordered probit stage (X).
+    :type offsetx: float
+    :param offsetz: Offset for covariates in the inflation stage.
+    :type offsetz: float
     """
     n = len(data)
     ycat = y.astype("category")
@@ -433,24 +437,26 @@ def miop(pstart, x, y, z, data, weights, offsetx, offsetz):
 def miopc(pstart, x, y, z, data, weights, offsetx, offsetz):
     """
     Likelihood function for Middle-inflated Correlated-Errors Model.
-    Number of outcomes must be odd.
+    
+    The number of categories in the dependent variable must be odd.
 
-    :param pstart: starting parameters.
-    :type pstart: numpy.ndarray or list
-    :param x: Ordered stage variables.
-    :type x: pandas.core.frame.DataFrame
-    :param y: Dependent Variable (DV).
-    :type y: pandas.core.frame.DataFrame
-    :param z: Inflation stage variables.
-    :type z: pandas.core.frame.DataFrame
-    :param data: dataset.
-    :type data: pandas.core.frame.DataFrame
-    :param weights: weights.
-    :type weights: int
-    :param offsetx: offset for X.
-    :type offsetx: int
-    :param offsetz: offset for z.
-    :type offsetz: int
+    :param pstart: A list of starting values for the estimation.
+        Length of the number of parameters to be estimated.
+    :type pstart: list
+    :param x: Covariates in the ordered probit stage.
+    :type x: pandas.DataFrame
+    :param y: The dependent variable (DV). 
+    :type y: pandas.DataFrame
+    :param z: Covariates in the inflation stage.
+    :type z: pandas.DataFrame
+    :param data: Dataset with missing values listwise deleted.
+    :type data: pandas.DataFrame
+    :param weights: Weights.
+    :type weights: float
+    :param offsetx: Offset for the ordered probit stage covariates (X).
+    :type offsetx: float
+    :param offsetz: Offset for the covariates in the inflation stage (Z).
+    :type offsetz: float
     """
     n = len(data)
     ycat = y.astype("category")
@@ -518,12 +524,16 @@ def miopc(pstart, x, y, z, data, weights, offsetx, offsetz):
 
 
 def opresults(model, data, x, y):
-    """Produce estimation results, part of :py:func:`opmod`.
+    """Produces estimation results, part of :py:func:`opmod`.
 
-    :param model: model object created from minimization.
-    :param data: dataset.
-    :param x: Independent variables.
-    :param y: : Dependent Variable.
+    :param model: Model estimation results obtained from minimization.
+    :param data: Dataset.
+    :type data: pandas.DataFrame
+    :param x: List of names for independent variables matching column names
+        in data.
+    :type x: list of str
+    :param y: : List of name for dependent Variablematching column names
+        in data.
     """
     varlist = np.unique(y + x)
     dataset = data[varlist]
@@ -565,16 +575,20 @@ def opresults(model, data, x, y):
 
 
 def opmod(data, x, y, pstart=None, method="BFGS", weights=1, offsetx=0):
-    """Estimate Ordered Probit model and return :class:`OpModel` class object.
+    """Estimates Ordered Probit model and returns :class:`OpModel` class object.
 
-    :param pstart: starting parameters.
-    :param data: full dataset.
+    :param pstart: A list of starting values for the estimation. 
+        Length of the number of parameters to be estimated.  
+    :type pstart: list
+    :param data: Full dataset used for estimation.
+    :type data: pandas.DataFrame
     :type x: list of str
     :param y: Dependent Variable (DV).
     :type y: list of str
-    :param method: method for optimization, default 'BFGS'.
-    :param weights: weights.
-    :param offsetx: offset for X.
+    :param method: Method for optimization, default is 'BFGS'. For other
+        available methods, see scipy.optimize.minimize documentation.
+    :param weights: Weights.
+    :param offsetx: Offset for covariates (X).
     :return: OpModel
     """
     varlist = np.unique(y + x)
@@ -591,7 +605,7 @@ def opmod(data, x, y, pstart=None, method="BFGS", weights=1, offsetx=0):
         pstart,
         args=(x_, yx_, datasetnew, weights, offsetx),
         method=method,
-        options={"gtol": 1e-6, "disp": True, "maxiter": 500},
+        options={"disp": True, "maxiter": 500},
     )
     results = opresults(model, data, x, y)
     return results
@@ -600,12 +614,16 @@ def opmod(data, x, y, pstart=None, method="BFGS", weights=1, offsetx=0):
 def iopresults(model, data, x, y, z, modeltype):
     """Produce estimation results, part of :py:func:`iopmod`.
 
-    :param model: model object created from minimization.
-    :param data: dataset.
-    :param x: Ordered stage variables.
-    :param y: : Dependent Variable (DV).
-    :param z: : Inflation stage variables.
-    :param modeltype: : 'ziop' or 'miop' model.
+    :param model: Model estimation results obtained from minimization.
+    :param data: Full dataset used for estimation.
+    :type data: pandas.DataFrame
+    :param x: List of names for covariates in the ordered probit stage.
+    :type x: list of str
+    :param y: : List of names for dependent cariable.
+    :type y: list of str
+    :param z: : List of names for covariates in the inflation stage.
+    :type z: list of str
+    :param modeltype: : Type of model. Options are: 'ziop' or 'miop'.
     """
     varlist = np.unique(y + z + x)
     dataset = data[varlist]
@@ -669,11 +687,15 @@ def iopresults(model, data, x, y, z, modeltype):
 def iopcresults(model, data, x, y, z, modeltype):
     """Produce estimation results, part of :py:func:`ziopc  mod`.
 
-    :param model: model object created from minimization.
-    :param data: dataset.
-    :param x: Ordered stage variables.
-    :param y: : Dependent Variable (DV).
-    :param z: : Inflation stage variables.
+    :param model: Model estimation results obtained from minimization.
+    :param data: Full dataset used for estimation.
+    :type data: pandas.DataFrame
+    :param x: List of names for covariates in the ordered probit stage.
+    :type x: list of str
+    :param y: : List of names for dependent cariable.
+    :type y: list of str
+    :param z: : List of names for covariates in the inflation stage.
+    :type z: list of str
     :param modeltype: : Type of model. Options are: 'ziopc' or 'miopc'
     """
     varlist = np.unique(y + z + x)
@@ -752,18 +774,27 @@ def iopmod(
 ):
     """Estimate ZiOP model and return :class:`IopModel` class object as output.
 
-    :param pstart: starting parameters.
-    :param data: full dataset.
-    :type x: list of str.
-    :param y: Dependent Variable (DV).
-    :type y: list of str.
-    :param z: Inflation stage variables.
-    :type z: list of str.
-    :param modeltype: must be one of "ziop" or 'miop'.
-    :param method: method for optimization, default 'BFGS'.
-    :param weights: weights.
-    :param offsetx: offset for X.
-    :param offsetz: offset for Z.
+    :param pstart: A list of starting values for the estimation.
+        Length of the number of parameters to be estimated.
+    :type pstart: list
+    :param data: Full dataset used for estimation.
+    :type data: pandas.DataFrame
+    :param x: Covariates in the ordered probit stage.
+        Elements must match column names of ``data``.
+    :type x: list of str
+    :param y: Dependent variable (DV). Element must match column
+        names of ``data``.
+    :type y: list of str
+    :param z: Inflation stage variable. Elements must match column
+        names of ``data``.
+    :type z: list of str
+    :param modeltype: Type of model to be estimated.
+        Options are: "ziop" or 'miop'.
+    :param method: Method for optimization, default 'BFGS'.  For other
+        available methods, see scipy.optimize.minimize documentation.
+    :param weights: Weights.
+    :param offsetx: Offset for ordered probit stage covariates (X).
+    :param offsetz: Offset for inflation stage covariates (Z).
     :return: IopModel
     """
     types = ["ziop", "miop"]
@@ -786,7 +817,7 @@ def iopmod(
                 pstart,
                 args=(x_, yx_, z_, datasetnew, weights, offsetx, offsetz),
                 method=method,
-                options={"gtol": 1e-6, "disp": True, "maxiter": 500},
+                options={"disp": True, "maxiter": 500},
             )
         elif modeltype == "miop":
             if len(np.unique(y_.astype("category").iloc[:, 0])) % 2 == 1:
@@ -795,7 +826,7 @@ def iopmod(
                     pstart,
                     args=(x_, yx_, z_, datasetnew, weights, offsetx, offsetz),
                     method=method,
-                    options={"gtol": 1e-6, "disp": True, "maxiter": 500},
+                    options={"disp": True, "maxiter": 500},
                 )
             else:
                 raise Exception("miop requires odd number of categories.")
@@ -819,18 +850,27 @@ def iopcmod(
 ):
     """Estimate an iOP model (ZiOP or MiOP) and return :class:`IopcModel`.
 
-    :param pstart: starting parameters.
-    :param data: dataset.
+    :param pstart: A list of starting values for the estimation.
+        Length of the number of parameters to be estimated.
+    :type pstart: list
+    :param data: Dataset used for estimation.
+    :type data: pandas.DataFrame
+    :param x: Covariates for the ordered probit stage.
+        Elements must match column names of ``data``.
     :type x: list of str
-    :param y: Dependent Variable (DV).
+    :param y: The dependent variable (DV). Element must match column
+        names of ``data``.
     :type y: list of str
-    :param z: Inflation stage variables.
+    :param z: Covariates for the inflation stage. Elements must match column
+        names of ``data``.
     :type z: list of str
-    :param modeltype: Type of model to be estimated ("ziopc" or 'miopc').
-    :param method: method for optimization, default 'BFGS'
-    :param weights: weights.
-    :param offsetx: offset for X.
-    :param offsetz: offset for Z.
+    :param modeltype: Type of model to be estimated.
+        Options are: 'ziopc' or 'miopc'.
+    :param method: Method for optimization, default is 'BFGS'. For other
+        available methods, see scipy.optimize.minimize documentation.
+    :param weights: Weights.
+    :param offsetx: Offset for variables in ordered probit stage (X).
+    :param offsetz: Offset for variables in inflation stage (Z).
     :return: IopCModel
     """
     types = ["ziopc", "miopc"]
@@ -855,7 +895,7 @@ def iopcmod(
                 pstart,
                 args=(x_, yx_, z_, datasetnew, weights, offsetx, offsetz),
                 method=method,
-                options={"gtol": 1e-6, "disp": True, "maxiter": 500},
+                options={"disp": True, "maxiter": 500},
             )
         elif modeltype == "miopc":
             if len(np.unique(y_.astype("category").iloc[:, 0])) % 2 == 1:
@@ -864,7 +904,7 @@ def iopcmod(
                     pstart,
                     args=(x_, yx_, z_, datasetnew, weights, offsetx, offsetz),
                     method=method,
-                    options={"gtol": 1e-6, "disp": True, "maxiter": 500},
+                    options={"disp": True, "maxiter": 500},
                 )
             else:
                 raise Exception("miopc requires odd number of categories.")
@@ -878,8 +918,8 @@ def iopcmod(
 def iopfit(model):
     """Calculate probabilities from :py:func:`iopmod`.
 
-    :param model: :class:IopModel object from :py:func:`iopmod`
-    :return: :class:FittedVals object with fitted values
+    :param model: :class:IopModel object from :py:func:`iopmod`.
+    :return: :class:FittedVals object with fitted values.
     """
     zg = model.Z.dot(model.inflate)
     xb = model.X.dot(model.ordered)
@@ -936,8 +976,8 @@ def iopfit(model):
 def iopcfit(model):
     """Calculate fitted probabilities from :py:func:`iopcmod`.
 
-    :param model: :class:`IopCModel` object from :py:func:`iopcmod`
-    :return: :class:`FittedVals` object with fitted values
+    :param model: :class:`IopCModel` object from :py:func:`iopcmod`.
+    :return: :class:`FittedVals` object with fitted values.
     """
     zg = model.Z.dot(model.inflate)
     xb = model.X.dot(model.ordered)
@@ -1027,7 +1067,7 @@ def vuong_opiop(opmodel, iopmodel):
 
     :param opmodel: The OP model from :class:`OpModel`.
     :param iopmodel: The ZiOP model from :class:`IopModel`.
-    :return: vuongopiop: Result of the Vuong test
+    :return: vuongopiop: Result of the Vuong test.
     """
     n1 = len(opmodel.data)
     y = iopmodel.Y
@@ -1078,7 +1118,7 @@ def vuong_opiopc(opmodel, iopcmodel):
 
     :param opmodel: The OP model from :class:`OpModel`.
     :param iopcmodel: The iOPC model from :class:`IopCModel`.
-    :return: vuongopiopc: Result of the Vuong test
+    :return: vuongopiopc: Result of the Vuong test.
     """
     n1 = len(opmodel.data)
     y = iopcmodel.Y
@@ -1129,14 +1169,16 @@ def split_effects(model, inflvar, nsims=10000):
     and chosen numerical variable is mean value + 1 standard deviation.
     Other variables are kept at 0 or mean value
     (Note: the current version of the function
-    recognize ordinal variables as numerical).
+    recognizes ordinal variables as numerical).
 
     :param model: :class:`IopModel` or :class:`IopCModel`.
-    :param inflvar: int representing the location of variable
+    :param inflvar: Number representing the location of variable
         in the split-probit equation.
         (attribute .inflate of :class:`IopModel` or :class:`IopCModel`)
-    :param nsims: number of simulated observations, default to 10000.
-    :return: changeprobs: a dataframe of the predicted
+    :type inflvar: int
+    :param nsims: Number of simulated observations, default is 10000.
+    :type nsims: int
+    :return: changeprobs: A dataframe of the predicted
         probabilities when there is change in the variable (1)
         versus original values (0).
     """
@@ -1188,20 +1230,22 @@ def ordered_effects(model, ordvar, nsims=10000):
     """Calculate the changes in probability in each outcome in OP stage.
 
     This function calculates predicted probabilities
-    when there is change in value of a variable
+    when there is a change in the value of a covariate
     in the ordered probit equation.
     The chosen dummy variable is changed from 0 to 1,
     and chosen numerical variable is mean value + 1 standard deviation.
     Other variables are kept at 0 or mean value
     (Note: the current version of the function
-    recognize ordinal variables as numerical).
+    recognizes ordinal variables as numerical).
 
     :param model: :class:`IopModel` or :class:`IopCModel`.
-    :param ordvar: int representing the location of variable
+    :param ordvar: Number representing the location of variable
         in the ordered probit equation.
         (attribute .ordered of :class:`IopModel` or :class:`IopCModel`)
-    :param nsims: number of simulated observations, default to 10000.
-    :return: changeprobs: a dataframe of the predicted
+    :type ordvar: int
+    :param nsims: Number of simulated observations, default is 10000.
+    :type nsims: int
+    :return: changeprobs: A dataframe of the predicted
         probabilities when there is change in the variable for each outcome (1)
         versus original values (0).
     """
@@ -1278,4 +1322,4 @@ def ordered_effects(model, ordvar, nsims=10000):
     for j in range(1, 2 * model.ycat, 2):
         newnames[j] = list(probs2.columns)[round((j - 1) / 2)]
     changeprobs.columns = newnames
-    return changeprobs
\ No newline at end of file
+    return changeprobs
